Learn R Programming

revulyticsR (version 0.0.3)

get_categories_and_events: Get All Categories and Events for a List of Product Ids

Description

Returns all of the unique categories and events (basic and advanced) for each product id.

Usage

get_categories_and_events(rev_product_ids, rev_session_id, rev_username)

Arguments

rev_product_ids

A vector of revulytics product id's for which you want active user data.

rev_session_id

Session ID established by the connection to Revulytics API. This can be obtained with revulytics_auth().

rev_username

Revulytics username.

Value

Data frame with categories, events and event type by product id.

Details

It is not recommended that your username be stored directly in your code. There are various methods and packages available that are more secure; this package does not require you to use any one in particular.

Examples

Run this code
# NOT RUN {
rev_user <- "my_username"
rev_pwd <- "super_secret"
product_ids_list <- c("123", "456", "789")
session_id <- revulytics_auth(rev_user, rev_pwd)  
category_event <- get_categories_and_events(product_ids_list, session_id, rev_user)
# }

Run the code above in your browser using DataLab